==> sumo_1.15.0+dfsg.orig.tar.xz: sumo-1_15_0/tests/netedit/shapeelements/poly/create/angle/test.py <==
#!/usr/bin/env python
# Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
# Copyright (C) 2009-2022 German Aerospace Center (DLR) and others.
# This program and the accompanying materials are made available under the
# terms of the Eclipse Public License 2.0 which is available at
# https://www.eclipse.org/legal/epl-2.0/
# This Source Code may also be made available under the following Secondary
# Licenses when the conditions for such availability set forth in the Eclipse
# Public License 2.0 are satisfied: GNU General Public License, version 2
# or later which is available at
# https://www.gnu.org/licenses/old-licenses/gpl-2.0-standalone.html
# SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later

# @file    test.py
# @author  Pablo Alvarez Lopez
# @date    2016-11-25

# import common functions for netedit tests
import os
import sys

testRoot = os.path.join(os.environ.get('SUMO_HOME', '.'), 'tests')
neteditTestRoot = os.path.join(
    os.environ.get('TEXTTEST_HOME', testRoot), 'netedit')
sys.path.append(neteditTestRoot)
import neteditTestFunctions as netedit  # noqa

# Open netedit
neteditProcess, referencePosition = netedit.setupAndStart(neteditTestRoot, ['--gui-testing-debug-gl'])

# go to shape mode
netedit.shapeMode()

# go to shape mode
netedit.changeElement("poly")

# change angle (invalid)
netedit.changeDefaultValue(netedit.attrs.Poly.create.angle, "dummyAngle")

# try to create polygon
netedit.createSquaredTAZ(referencePosition, 182, 130, 200, True)

# change angle (valid, but > 360)
netedit.changeDefaultValue(netedit.attrs.Poly.create.angle, "365")

# try to create polygon
netedit.createSquaredPoly(referencePosition, 282, 130, 200, True)

# change angle (valid, < 0)
netedit.changeDefaultValue(netedit.attrs.Poly.create.angle, "-5")

# create polygon
netedit.createSquaredPoly(referencePosition, 382, 130, 200, True)

# change angle (0 < angle < 360)
netedit.changeDefaultValue(netedit.attrs.Poly.create.angle, "5")

# create polygon
netedit.createSquaredPoly(referencePosition, 482, 130, 200, True)

# Check undo redo
netedit.undo(referencePosition, 3)
netedit.redo(referencePosition, 3)

# save shapes
netedit.saveAdditionals(referencePosition)

# save network
netedit.saveNetwork(referencePosition)

# quit netedit
netedit.quit(neteditProcess)

==> sumo_1.18.0+dfsg.orig.tar.xz: sumo-1_18_0/tests/netedit/shapeelements/poly/create/angle/test.py <==
#!/usr/bin/env python
# Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.dev/sumo
# Copyright (C) 2009-2023 German Aerospace Center (DLR) and others.
# This program and the accompanying materials are made available under the
# terms of the Eclipse Public License 2.0 which is available at
# https://www.eclipse.org/legal/epl-2.0/
# This Source Code may also be made available under the following Secondary
# Licenses when the conditions for such availability set forth in the Eclipse
# Public License 2.0 are satisfied: GNU General Public License, version 2
# or later which is available at
# https://www.gnu.org/licenses/old-licenses/gpl-2.0-standalone.html
# SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later

# @file    test.py
# @author  Pablo Alvarez Lopez
# @date    2016-11-25

# import common functions for netedit tests
import os
import sys

testRoot = os.path.join(os.environ.get('SUMO_HOME', '.'), 'tests')
neteditTestRoot = os.path.join(
    os.environ.get('TEXTTEST_HOME', testRoot), 'netedit')
sys.path.append(neteditTestRoot)
import neteditTestFunctions as netedit  # noqa

# Open netedit
neteditProcess, referencePosition = netedit.setupAndStart(neteditTestRoot)

# go to shape mode
netedit.shapeMode()

# go to shape mode
netedit.changeElement("poly")

# change angle (invalid)
netedit.changeDefaultValue(netedit.attrs.Poly.create.angle, "dummyAngle")

# try to create polygon
netedit.createSquaredTAZ(referencePosition, 210, 136, 200, True)

# change angle (valid, but > 360)
netedit.changeDefaultValue(netedit.attrs.Poly.create.angle, "365")

# try to create polygon
netedit.createSquaredPoly(referencePosition, 401, 136, 200, True)

# change angle (valid, < 0)
netedit.changeDefaultValue(netedit.attrs.Poly.create.angle, "-5")

# create polygon
netedit.createSquaredPoly(referencePosition, 592, 136, 200, True)

# change angle (0 < angle < 360)
netedit.changeDefaultValue(netedit.attrs.Poly.create.angle, "5")

# create polygon
netedit.createSquaredPoly(referencePosition, 482, 130, 200, True)

# Check undo redo
netedit.undo(referencePosition, 3)
netedit.redo(referencePosition, 3)

# save Netedit config
netedit.saveNeteditConfig(referencePosition)

# quit netedit
netedit.quit(neteditProcess)
